@@ -13,8 +13,8 @@
 
 #include "ipc-client.h"
 #include "../src/globals.h"
-#include "../src/utils.h"
 #include "../src/ipc-protocol.h"
+#include "client-utils.h"
 
 #define HERBSTCLIENT_VERSION_STRING \
     "herbstclient " HERBSTLUFT_VERSION " (built on " __DATE__ ")\n"
@@ -24,6 +24,8 @@ void init_hook_regex(int argc, char* argv[]);
 void destroy_hook_regex();
 
 int g_ensure_newline = 1; // if set, output ends with a newline
+bool g_null_char_as_delim = false; // if true, the null character is used as delimiter
+bool g_print_last_arg_only = false; // if true, prints only the last argument of a hook
 int g_wait_for_hook = 0; // if set, do not execute command but wait
 bool g_quiet = false;
 regex_t* g_hook_regex = NULL;
@@ -80,6 +82,9 @@ void print_help(char* command, FILE* file) {
         "Options:\n"
         "\t-n, --no-newline: Do not print a newline if output does not end "
             "with a newline.\n"
+        "\t-0, --print0: Use the null character as delimiter between the "
+            "output of hooks.\n"
+        "\t-l, --last-arg: Print only the last argument of a hook.\n"
         "\t-i, --idle: Wait for hooks instead of executing commands.\n"
         "\t-w, --wait: Same as --idle but exit after first --count hooks.\n"
         "\t-c, --count COUNT: Let --wait exit after COUNT hooks were "
@@ -125,11 +130,22 @@ int main_hook(int argc, char* argv[]) {
             }
         }
         if (print_signal) {
-            // just print as list
-            for (int i = 0; i < hook_argc; i++) {
-                printf("%s%s", i ? "\t" : "", hook_argv[i]);
+            if (g_print_last_arg_only) {
+                // just drop hooks without content
+                if (hook_argc >= 1) {
+                    printf("%s", hook_argv[hook_argc-1]);
+                }
+            } else {
+                // just print as list
+                for (int i = 0; i < hook_argc; i++) {
+                    printf("%s%s", i ? "\t" : "", hook_argv[i]);
+                }
+            }
+            if (g_null_char_as_delim) {
+                putchar(0);
+            } else {
+                printf("\n");
             }
-            printf("\n");
             fflush(stdout);
         }
         argv_free(hook_argc, hook_argv);
@@ -151,6 +167,8 @@ int main_hook(int argc, char* argv[]) {
 int main(int argc, char* argv[]) {
     static struct option long_options[] = {
         {"no-newline", 0, 0, 'n'},
+        {"print0", 0, 0, '0'},
+        {"last-arg", 0, 0, 'l'},
         {"wait", 0, 0, 'w'},
         {"count", 1, 0, 'c'},
         {"idle", 0, 0, 'i'},
@@ -162,7 +180,7 @@ int main(int argc, char* argv[]) {
     // parse options
     while (1) {
         int option_index = 0;
-        int c = getopt_long(argc, argv, "+nwc:iqhv", long_options, &option_index);
+        int c = getopt_long(argc, argv, "+n0lwc:iqhv", long_options, &option_index);
         if (c == -1) break;
         switch (c) {
             case 'i':
@@ -179,6 +197,12 @@ int main(int argc, char* argv[]) {
             case 'n':
                 g_ensure_newline = 0;
                 break;
+            case '0':
+                g_null_char_as_delim = true;
+                break;
+            case 'l':
+                g_print_last_arg_only = true;
+                break;
             case 'q':
                 g_quiet = true;
                 break;
