@@ -44,6 +44,7 @@ const std::array<const char*,NetCOUNT>g_netatom_names =
     { NetSupported                   , "_NET_SUPPORTED"                    },
     { NetClientList                  , "_NET_CLIENT_LIST"                  },
     { NetClientListStacking          , "_NET_CLIENT_LIST_STACKING"         },
+    { NetCloseWindow                 , "_NET_CLOSE_WINDOW"                 },
     { NetNumberOfDesktops            , "_NET_NUMBER_OF_DESKTOPS"           },
     { NetCurrentDesktop              , "_NET_CURRENT_DESKTOP"              },
     { NetDesktopNames                , "_NET_DESKTOP_NAMES"                },
@@ -424,6 +425,11 @@ void ewmh_handle_client_message(XEvent* event) {
             break;
         }
 
+        case NetCloseWindow: {
+            window_close(me->window);
+            break;
+        }
+
         default:
             HSDebug("no handler for the client message \"%s\"\n",
                     g_netatom_names[index]);
