@@ -1,4 +1,4 @@
-/** Copyright 2011-2012 Thorsten Wißmann. All rights reserved.
+/** Copyright 2011-2013 Thorsten Wißmann. All rights reserved.
  *
  * This software is licensed under the "Simplified BSD License".
  * See LICENSE for details */
@@ -8,8 +8,8 @@
 
 /**
  * This file re-implements newer glib functions that are missing in glib on
- * older systems. Note that this is mostly works correctly but isn't as
- * efficient. As the new glib function.
+ * older systems. Note that this mostly works correctly but isn't as
+ * efficient as the new glib functions.
  */
 
 #include <glib.h>
@@ -30,5 +30,21 @@
 
 #endif
 
+
+
+#if !(GLIB_CHECK_VERSION(2, 28, 0))
+/**
+ * g_list_free_full
+ *
+ * actually this is not c-standard-compatible because of casting
+ * an one-parameter-function to an 2-parameter-function.
+ * but it should work on almost all architectures (maybe not amd64?)
+ */
+#define g_list_free_full(LIST, DESTROY) do {            \
+        g_list_foreach((LIST), (GFunc)(DESTROY), 0);    \
+        g_list_free((LIST));                            \
+    } while(0)
+#endif
+
 #endif
 
