@@ -22,7 +22,7 @@ typedef struct KeyBinding {
 } KeyBinding;
 
 unsigned int modifiername2mask(const char* name);
-char*   modifiermask2name(unsigned int mask);
+const char* modifiermask2name(unsigned int mask);
 
 bool string2modifiers(char* string, unsigned int* modmask);
 bool string2key(char* string, unsigned int* modmask, KeySym* keysym);
@@ -35,10 +35,10 @@ int list_keysyms(int argc, char** argv, GString* output);
 bool key_remove_bind_with_keysym(unsigned int modifiers, KeySym sym);
 void key_remove_all_binds();
 GString* keybinding_to_g_string(KeyBinding* binding);
-void key_find_binds(char* needle, GString* output);
-void complete_against_modifiers(char* needle, char seperator,
+void key_find_binds(const char* needle, GString* output);
+void complete_against_modifiers(const char* needle, char seperator,
                                 char* prefix, GString* output);
-void complete_against_keysyms(char* needle, char* prefix, GString* output);
+void complete_against_keysyms(const char* needle, char* prefix, GString* output);
 void regrab_keys();
 void grab_keybind(KeyBinding* binding, void* useless_pointer);
 void update_numlockmask();
