@@ -520,8 +520,19 @@ void event_on_configure(XEvent event) {
             bool height_requested = 0 != (cre->value_mask & CWHeight);
             bool x_requested = 0 != (cre->value_mask & CWX);
             bool y_requested = 0 != (cre->value_mask & CWY);
-            cre->width += 2*cre->border_width;
-            cre->height += 2*cre->border_width;
+            // find monitor appropriate for client
+            HSMonitor* m = find_monitor_with_tag(client->tag);
+            if (!m) {
+                m = monitor_with_coordinate(client->float_size.x,
+                                            client->float_size.y);
+                if (!m) {
+                    m = get_current_monitor();
+                }
+            }
+            // requested coordinates are relative to the root window.
+            // convert them to coordinates relative to the monitor;
+            cre->x -= m->rect.x + m->pad_left;
+            cre->y -= m->rect.y + m->pad_up;
             if (width_requested && newRect.width  != cre->width) changes = true;
             if (height_requested && newRect.height != cre->height) changes = true;
             if (x_requested || y_requested) changes = true;
@@ -782,6 +793,7 @@ static struct {
     { object_tree_init, object_tree_destroy },
     { key_init,         key_destroy         },
     { settings_init,    settings_destroy    },
+    { reload_tree_style,NULL                },
     { floating_init,    floating_destroy    },
     { stacklist_init,   stacklist_destroy   },
     { layout_init,      layout_destroy      },
@@ -903,7 +915,7 @@ void motionnotify(XEvent* event) {
 }
 
 void mapnotify(XEvent* event) {
-    //HSDebug("name is: MapNotify\n");
+    HSDebug("name is: MapNotify for %lx\n", event->xmap.window);
     HSClient* c;
     if ((c = get_client_from_window(event->xmap.window))) {
         // reset focus. so a new window gets the focus if it shall have the
@@ -911,6 +923,9 @@ void mapnotify(XEvent* event) {
         frame_focus_recursive(g_cur_frame);
         // also update the window title - just to be sure
         client_update_title(c);
+    } else {
+        HSDebug("MapNotify: briefly managing %lx to apply rules\n", event->xmap.window);
+        manage_client(event->xmap.window, true);
     }
 }
 
@@ -990,7 +1005,9 @@ int main(int argc, char* argv[]) {
 
     // initialize subsystems
     for (int i = 0; i < LENGTH(g_modules); i++) {
-        g_modules[i].init();
+        if (g_modules[i].init) {
+            g_modules[i].init();
+        }
     }
     fetch_settings();
 
@@ -1016,18 +1033,22 @@ int main(int argc, char* argv[]) {
         if (g_aboutToQuit) {
             break;
         }
-        while (XPending(g_display)) {
+        XSync(g_display, False);
+        while (XQLength(g_display)) {
             XNextEvent(g_display, &event);
             void (*handler) (XEvent*) = g_default_handler[event.type];
             if (handler != NULL) {
                 handler(&event);
             }
+            XSync(g_display, False);
         }
     }
 
     // destroy all subsystems
     for (int i = LENGTH(g_modules); i --> 0;) {
-        g_modules[i].destroy();
+        if (g_modules[i].destroy) {
+            g_modules[i].destroy();
+        }
     }
     XCloseDisplay(g_display);
     // check if we shall restart an other window manager
