@@ -16,6 +16,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <assert.h>
 #include "glib-backports.h"
 
 // gui
@@ -27,6 +28,7 @@
 
 static Point2D          g_button_drag_start;
 static Rectangle        g_win_drag_start;
+static bool             g_drag_init_done;
 static HSClient*        g_win_drag_client = NULL;
 static HSMonitor*       g_drag_monitor = NULL;
 static MouseDragFunction g_drag_function = NULL;
@@ -62,6 +64,7 @@ void mouse_destroy() {
 void mouse_handle_event(XEvent* ev) {
     XButtonEvent* be = &(ev->xbutton);
     MouseBinding* b = mouse_binding_find(be->state, be->button);
+    // TODO: get events from frames, too.
     HSClient* client = get_client_from_window(ev->xbutton.window);
     if (!b || !client) {
         // there is no valid bind for this type of mouse event
@@ -77,12 +80,18 @@ void mouse_initiate_move(HSClient* client, int argc, char** argv) {
 
 void mouse_initiate_zoom(HSClient* client, int argc, char** argv) {
     (void) argc; (void) argv;
-    mouse_initiate_drag(client, mouse_function_zoom);
+    if (is_client_floated(client))
+	mouse_initiate_drag(client, mouse_function_zoom);
+    else return;
 }
 
 void mouse_initiate_resize(HSClient* client, int argc, char** argv) {
     (void) argc; (void) argv;
-    mouse_initiate_drag(client, mouse_function_resize);
+    if (is_client_floated(client)) {
+        mouse_initiate_drag(client, mouse_function_resize_floated);
+    } else {
+        mouse_initiate_drag(client, mouse_function_resize_tiled);
+    }
 }
 
 void mouse_call_command(struct HSClient* client, int argc, char** argv) {
@@ -97,8 +106,7 @@ void mouse_initiate_drag(HSClient* client, MouseDragFunction function) {
     g_drag_function = function;
     g_win_drag_client = client;
     g_drag_monitor = find_monitor_with_tag(client->tag);
-    if (!g_drag_monitor || client->tag->floating == false) {
-        // only can drag wins in  floating mode
+    if (!g_drag_monitor) {
         g_win_drag_client = NULL;
         g_drag_function = NULL;
         return;
@@ -106,6 +114,7 @@ void mouse_initiate_drag(HSClient* client, MouseDragFunction function) {
     client_set_dragged(g_win_drag_client, true);
     g_win_drag_start = g_win_drag_client->float_size;
     g_button_drag_start = get_cursor_position();
+    g_drag_init_done = false;
     XGrabPointer(g_display, client->window, True,
         PointerMotionMask|ButtonReleaseMask, GrabModeAsync,
             GrabModeAsync, None, None, CurrentTime);
@@ -309,7 +318,107 @@ void mouse_function_move(XMotionEvent* me) {
     client_resize_floating(g_win_drag_client, g_drag_monitor);
 }
 
-void mouse_function_resize(XMotionEvent* me) {
+void mouse_function_resize_tiled(XMotionEvent* me) {
+    static HSFrame* parent;
+    static int orig_fraction;
+    if (g_drag_init_done == false) {
+        g_drag_init_done = true;
+        /* initialize local state */
+        HSClient* client = g_win_drag_client;
+        HSTag* tag = client->tag;
+        HSFrame* root = tag->frame;
+        HSFrame* frame = find_frame_with_client(root, client);
+        Rectangle* rect = &frame->last_rect;
+
+        // relative x/y coords in drag window
+        int rel_x = g_button_drag_start.x - rect->x;
+        int rel_y = g_button_drag_start.y - rect->y;
+
+        /*
+         * In which order should we search for neighbours?
+         * If we end up in the upper left triangle (M),
+         * the search order is "lurd" - left, up, right, down.
+         *
+         *          Up
+         *       +-------+
+         *       |\  |  /|
+         *       |M\ | / |
+         *       |MM\|/  |
+         * Left  |---X---| Right
+         *       |  /|\  |
+         *       | / | \ |
+         *       |/  |  \|
+         *       +-------+
+         *         Down
+         */
+
+        bool tr = false; /* top-right half */
+        bool tl = false; /* top-left half */
+        double slope = (double)rect->height / rect->width;
+        char direction[4];
+        if (rel_y < slope * rel_x)
+            tr = true;
+        if (rel_y < rect->height - slope * rel_x)
+            tl = true;
+        if (tl && tr) { direction[0] = 'u'; direction[2] = 'd'; }
+        else if (tl)  { direction[0] = 'l'; direction[2] = 'r'; }
+        else if (tr)  { direction[0] = 'r'; direction[2] = 'l'; }
+        else	      { direction[0] = 'd'; direction[2] = 'u'; }
+
+        switch (direction[0]) {
+            case 'l':
+            case 'r':
+                if (rel_y < rect->height/2)
+                { direction[1] = 'u'; direction[3] = 'd'; }
+                else { direction[1] = 'd'; direction[3] = 'u'; }
+                break;
+            case 'u':
+            case 'd':
+                if (rel_x < rect->width/2)
+                { direction[1] = 'l'; direction[3] = 'r'; }
+                else { direction[1] = 'r'; direction[3] = 'l'; }
+                break;
+            default:
+                assert(false); break;
+        }
+
+        HSFrame* neighbour = NULL;
+        int i=0;
+        do neighbour = frame_neighbour(frame, direction[i]);
+        while (!neighbour && ++i < sizeof(direction));
+        if (!neighbour) return;
+
+        parent = neighbour->parent;
+        assert(parent != NULL); // if has neighbour, it also must have a parent
+        assert(parent->type == TYPE_FRAMES);
+        assert(direction[i] == 'l' || direction[i] == 'r'
+                || direction[i] == 'u' || direction[i] == 'd');
+        assert(parent->content.layout.align ==
+                (direction[i] == 'r' || direction[i] == 'l'
+                 ? ALIGN_HORIZONTAL : ALIGN_VERTICAL));
+        orig_fraction = parent->content.layout.fraction;
+    }
+
+    if (!parent) return;
+    int delta, total;
+    if (parent->content.layout.align == ALIGN_HORIZONTAL) {
+        delta = me->x_root - g_button_drag_start.x;
+        total = parent->last_rect.width;
+    } else {
+        delta = me->y_root - g_button_drag_start.y;
+        total = parent->last_rect.height;
+    }
+    assert(total > 0);
+
+    parent->content.layout.fraction =
+        CLAMP(orig_fraction + FRACTION_UNIT * delta / total,
+                (int)(FRAME_MIN_FRACTION * FRACTION_UNIT),
+                (int)((1.0 - FRAME_MIN_FRACTION) * FRACTION_UNIT));
+
+    frame_apply_layout(parent, parent->last_rect);
+}
+
+void mouse_function_resize_floated(XMotionEvent* me) {
     int x_diff = me->x_root - g_button_drag_start.x;
     int y_diff = me->y_root - g_button_drag_start.y;
     g_win_drag_client->float_size = g_win_drag_start;
