@@ -57,12 +57,14 @@ typedef struct {
 
 typedef struct {
     GString*        tag_name;
+    GString*        monitor_name;
     GString*        tree_index;
     bool            focus; // if client should get focus
     bool            switchtag; // if the tag may be switched for focusing it
     bool            manage; // whether we should manage it
     bool            fullscreen;
     bool            ewmhnotify; // whether to send ewmh-notifications
+    GString*        keymask; // Which keymask rule should be applied for this client
 } HSClientChanges;
 
 void rules_init();
@@ -83,4 +85,3 @@ int rule_print_all_command(int argc, char** argv, GString* output);
 void complete_against_rule_names(int argc, char** argv, int pos, GString* output);
 
 #endif
-
