@@ -6,7 +6,8 @@
 #include <stdbool.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
-#include "utils.h"
+
+#include "x11-types.h"
 
 
 // cut a rect out of the window, s.t. the window has geometry rect and a frame
@@ -14,5 +15,7 @@
 void window_cut_rect_hole(Window win, int width, int height, int framewidth);
 void window_make_intransparent(Window win, int width, int height);
 
+Point2D get_cursor_position();
+
 #endif
 
